summaryrefslogtreecommitdiffstats
path: root/debian/_buildscripts/local/internals/_pbuilder.sh
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2020-04-22 23:30:09 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2020-04-22 23:31:31 +0900
commit8d146a12a7b3772d0f38f036a2c0e362b33c8866 (patch)
tree269edb1f4b7374cbbf1b278f6646fd580c8a0763 /debian/_buildscripts/local/internals/_pbuilder.sh
parent403333c7318640cefe37237106de114310187f78 (diff)
downloadtde-packaging-8d146a12a7b3772d0f38f036a2c0e362b33c8866.tar.gz
tde-packaging-8d146a12a7b3772d0f38f036a2c0e362b33c8866.zip
DEB build scripts: added support for reproducible builds.
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'debian/_buildscripts/local/internals/_pbuilder.sh')
-rwxr-xr-xdebian/_buildscripts/local/internals/_pbuilder.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/debian/_buildscripts/local/internals/_pbuilder.sh b/debian/_buildscripts/local/internals/_pbuilder.sh
index 51ba48dc6..cbcded647 100755
--- a/debian/_buildscripts/local/internals/_pbuilder.sh
+++ b/debian/_buildscripts/local/internals/_pbuilder.sh
@@ -44,9 +44,9 @@ function run_pdebuild()
echo "deb [trusted=yes] file:$TDE_DEBS_DIR ./" >> /etc/apt/sources.list
END_D05_01
if [[ "$USE_PREBUILD_EXTRA_DEPS" = "y" ]]; then
- # Get building branch from .tdescmrevision file
- if [[ -f "$MOD_BUILD_PATH/.tdescmrevision" ]]; then
- BUILD_BRANCH=`sed -r "s/([^-]+)-.*/\1/" "$MOD_BUILD_PATH/.tdescmrevision"`
+ # Get building branch from .tdescminfo file
+ if [[ -f "$MOD_BUILD_PATH/.tdescminfo" ]]; then
+ BUILD_BRANCH=`sed -n -r "s/^Revision: ([^-]+)-.*/\1/p" "$MOD_BUILD_PATH/.tdescminfo"`
OLD_IFS=$IFS && IFS=$' \t'
while read l_branch l_repo l_component; do
if [ "$l_branch" = "$BUILD_BRANCH" ]; then